__version__ = "0.6.1"
__git_commiter_name__ = "Guy Rozendorn"
__git_commiter_email__ = "guy@rzn.co.il"
__git_branch__ = '(detached from v0.6.1)'
__git_remote_tracking_branch__ = '(No remote tracking)'
__git_remote_url__ = '(Not remote tracking)'
__git_head_hash__ = 'bbe51ab5b2d65cb8ef76399a8f2bdb0531027a0a'
__git_head_subject__ = 'HOSTDEV-1095 new bootstrap'
__git_head_message__ = '================================================================================\n\nHost Infrastructure / HOSTDEV-1095\nbootstrap fails if older zc.buildout is installed\n\nType:              Bug                               Status:        Open                       Assignee: Guy Rozendorn\nPriority:          Minor                             Resolution:    Unresolved                 Reporter: Guy Rozendorn\nAffects Version/s:                                   Fix Version/s: 0.30\nComponents: packaging                                                                          Created: 2013-07-07 16:59\nLabels:                                                                                        Updated: 2013-07-07 16:59\n\nIssue Links:\n\nSub-Tasks:\n\nDescription:\n\nComments:'
__git_dirty_diff__ = ''